#ifndef PPDFVIEWER_H
#define PPDFVIEWER_H

#include <qvbox.h>
#include <qscrollview.h>
#include <qimage.h>
#include <qtoolbutton.h>
#include <qpushbutton.h>

#if defined (Q_OS_WIN32)
	class QAxWidget;
#endif
#if defined (Q_WS_X11)
	//	
#endif
#if defined (Q_WS_MACX)
	//
#endif

class QToolButton;
class QLabel;
class QProgressDialog;

class PButton : public QPushButton
{
public:
	PButton(QString str, QWidget*);
	PButton(const QIconSet &, QString str, QWidget*);

protected:
	void focusInEvent(QFocusEvent*);
	void focusOutEvent(QFocusEvent*);
	void leaveEvent(QEvent*);
	void enterEvent(QEvent*);
};

class PToolButtonRep: public QToolButton
{
	Q_OBJECT

public:
	PToolButtonRep(QWidget*);

	void setInterval(int);
	void stopRepeate();

public slots:
	void setEnabled(bool);

private slots:
	void repeateSignal();

signals:
	void downHolded();

private:
	QTimer* timer;
	int startInt;
	bool stopMe;

protected:
	void mousePressEvent(QMouseEvent*);
	void mouseReleaseEvent(QMouseEvent*);
};

class PPdfView : public QScrollView
{
	Q_OBJECT
public:
	PPdfView(QWidget* parent=0, const char* name=0, WFlags f=0);

	~PPdfView();

	QHBox* hbTop;

	void init();

	void enableAdobeReader();
	void disableAdobeReader();

	bool getAdobeReader();
	QString version();

	enum {
	  FitNo =0,
	  FitH  =1,
	  FitHV =2
	};

	QPixmap* viewPixmap;

	bool bColor;

	int pageCurrent;
	int pageCount;
	int pageHeight;

	void setData(QString fileName, int layout=FitHV, QString ownerPassword="", QString userPassword="");
	void setData(char* data, uint len, int layout=FitHV, QString ownerPassword="", QString userPassword="");

	int load(QString fileNamePdf, int layout, double resolution=72, int mode=8, QString ownerPassword="", QString userPassword="");
	int loadFromData(char* data, uint len, int layout=FitHV, double resolution=72, int mode=8, QString ownerPassword="", QString userPassword="");

	void setSizeH(double );
	void setSizeHV(double, double);

	void setLeftMargin(int);
	void setPageDistance(int);

public slots:
	void setSizeFitH();
	void setSizeFitHV();
	void gotoPrevPage();
	void gotoNextPage();
	void gotoPage(int);

	void open();
	void saveAs();

	void load(const QString&);
	void loadData();

	void setColor();
	void extractText();
	void buildJpg();

	void showInSystemViewer();

	void updateView();

	void print(QString fileName, QString ownerPassword="", QString userPassword="");
	void print();

	void printWithDialog(QString fileName, QString ownerPassword="", QString userPassword="");
	void printWithDialog();

	void printCurrentPage();

	QString printData(char* data, uint len, QPrinter* printer, int page=-1, QProgressDialog* progress=0, bool isColor=false, QString ownerPassword="", QString userPassword="");

	void setView(QString);

signals:
	void droppedFileName(const QString&);
	void pageChanged(const QString&);
	void printingPage(int, int);
	void sendPageCount(int);

protected:
	void drawContents(QPainter*, int, int, int, int);
	void dragEnterEvent(QDragEnterEvent*);
	void dropEvent(QDropEvent*);
	void contentsWheelEvent(QWheelEvent*);
	void viewportResizeEvent(QResizeEvent*);

public:
	char* dataFromFile;
	uint dataLen;

private:
	QPtrList<QImage> imageList;

	QString fileNamePdf;

	int viewLayout;

	int deltaV;
	int deltaH;

	double resolutionStd;
	double resolutionCur;

	QString userPW;
	QString ownerPW;

	int scaleWidth;
	int scaleHeight;

	#if defined (Q_OS_WIN32)
		QAxWidget* reader;
	#endif

	bool bWithAdobe;
};

class PPdfViewer : public QVBox
{
	Q_OBJECT
public:
	PPdfViewer(QWidget* parent=0, const char* name=0, WFlags f=0);

	~PPdfViewer();

	PPdfView* pdfView();

	void showToolBarTop(bool);
	void showToolBarBottom(bool);

	void reduceButtons();

	static const char* pdfCaption[];
	static const char* pdfFitHV[];
	static const char* pdfFitH[];
	static const char* pdfPageUp[];
	static const char* pdfPageDown[];
	static const char* pdfZoomPlus[];
	static const char* pdfZoomMinus[];
	static const char* pdfPrint[];
	static const char* pdfFileSaveAs[];
	static const char* pdfFileOpen[];
	static const char* pdfSymbol[];
	static const char* pdfGrayScale[];
	static const char* pdfColor[];
	static const char* pdfText[];
	static const char* pdfHtml[];
	static const char* pdfJpg[];
	

public slots:
	void setColor();
	void setPageLabelWidth(const QString&);
	void setCaptionText(const QString&);
	void updateButtons(int);

protected:
	void keyPressEvent(QKeyEvent*);

private:
	PPdfView* view;

	QHBox* hbTop;
	QHBox* hbBottom;

	QLabel* lblPage;

	QToolButton* tbFileOpen;
	QToolButton* tbFileSaveAs;
	PToolButtonRep* tbPrevPage;
	PToolButtonRep* tbNextPage;
	QToolButton* tbFitH;
	QToolButton* tbFitHV;
	QToolButton* tbColor;
	QToolButton* tbText;
	QToolButton* tbJpg;
	QToolButton* tbPrint;

	PButton* pbPrint;
	PButton* pbPrintWithDialog;
	PButton* pbPrintCurrentPage;
	PButton* pbShowInSystem;
};


#endif
